from enum import Enum


class Gebiettyp(str, Enum):
    """
    List of possible Gebiettypen.
    """

    REGELZONE = "REGELZONE"
    MARKTGEBIET = "MARKTGEBIET"
    BILANZIERUNGSGEBIET = "BILANZIERUNGSGEBIET"
    VERTEILNETZ = "VERTEILNETZ"
    TRANSPORTNETZ = "TRANSPORTNETZ"
    REGIONALNETZ = "REGIONALNETZ"
    AREALNETZ = "AREALNETZ"
    GRUNDVERSORGUNGSGEBIET = "GRUNDVERSORGUNGSGEBIET"
    VERSORGUNGSGEBIET = "VERSORGUNGSGEBIET"
