"""
Bundles all datasets for the loaders
"""
from ibims.datasets.agent_hint_loader import ED4AgentHintLoaderDataSet
from ibims.datasets.base import DataSetBaseModel
from ibims.datasets.customer_loader import TripicaCustomerLoaderDataSet
from ibims.datasets.document_loader import TripicaDocumentLoaderDataSet
from ibims.datasets.invoice_loader import InvoiceLoaderDataSet
from ibims.datasets.network_loader import TripicaNetworkLoaderDataSet
from ibims.datasets.quantities_loader import QuantitiesLoaderDataSet
from ibims.datasets.resource_loader import TripicaResourceLoaderDataSet
from ibims.datasets.usage_loader import TripicaUsageLoaderDataSet
