from enum import Enum


class BDEWArtikelnummer(str, Enum):
    """
    BDEW Artikelnummern
    """

    LEISTUNG = "LEISTUNG"
    LEISTUNG_PAUSCHAL = "LEISTUNG_PAUSCHAL"
    GRUNDPREIS = "GRUNDPREIS"
    REGELENERGIE_ARBEIT = "REGELENERGIE_ARBEIT"
    REGELENERGIE_LEISTUNG = "REGELENERGIE_LEISTUNG"
    NOTSTROMLIEFERUNG_ARBEIT = "NOTSTROMLIEFERUNG_ARBEIT"
    NOTSTROMLIEFERUNG_LEISTUNG = "NOTSTROMLIEFERUNG_LEISTUNG"
    RESERVENETZKAPAZITAET = "RESERVENETZKAPAZITAET"
    RESERVELEISTUNG = "RESERVELEISTUNG"
    ZUSAETZLICHE_ABLESUNG = "ZUSAETZLICHE_ABLESUNG"
    PRUEFGEBUEHREN_AUSSERPLANMAESSIG = "PRUEFGEBUEHREN_AUSSERPLANMAESSIG"
    WIRKARBEIT = "WIRKARBEIT"
    SINGULAER_GENUTZTE_BETRIEBSMITTEL = "SINGULAER_GENUTZTE_BETRIEBSMITTEL"
    ABGABE_KWKG = "ABGABE_KWKG"
    ABSCHLAG = "ABSCHLAG"
    KONZESSIONSABGABE = "KONZESSIONSABGABE"
    ENTGELT_FERNAUSLESUNG = "ENTGELT_FERNAUSLESUNG"
    UNTERMESSUNG = "UNTERMESSUNG"
    BLINDMEHRARBEIT = "BLINDMEHRARBEIT"
    ENTGELT_ABRECHNUNG = "ENTGELT_ABRECHNUNG"
    SPERRKOSTEN = "SPERRKOSTEN"
    ENTSPERRKOSTEN = "ENTSPERRKOSTEN"
    MAHNKOSTEN = "MAHNKOSTEN"
    MEHR_MINDERMENGEN = "MEHR_MINDERMENGEN"
    INKASSOKOSTEN = "INKASSOKOSTEN"
    BLINDMEHRLEISTUNG = "BLINDMEHRLEISTUNG"
    ENTGELT_MESSUNG_ABLESUNG = "ENTGELT_MESSUNG_ABLESUNG"
    ENTGELT_EINBAU_BETRIEB_WARTUNG_MESSTECHNIK = "ENTGELT_EINBAU_BETRIEB_WARTUNG_MESSTECHNIK"
    AUSGLEICHSENERGIE = "AUSGLEICHSENERGIE"
    ZAEHLEINRICHTUNG = "ZAEHLEINRICHTUNG"
    WANDLER_MENGENUMWERTER = "WANDLER_MENGENUMWERTER"
    KOMMUNIKATIONSEINRICHTUNG = "KOMMUNIKATIONSEINRICHTUNG"
    TECHNISCHE_STEUEREINRICHTUNG = "TECHNISCHE_STEUEREINRICHTUNG"
    PARAGRAF_19_STROM_NEV_UMLAGE = "PARAGRAF_19_STROM_NEV_UMLAGE"
    BEFESTIGUNGSEINRICHTUNG = "BEFESTIGUNGSEINRICHTUNG"
    OFFSHORE_HAFTUNGSUMLAGE = "OFFSHORE_HAFTUNGSUMLAGE"
    FIXE_ARBEITSENTGELTKOMPONENTE = "FIXE_ARBEITSENTGELTKOMPONENTE"
    FIXE_LEISTUNGSENTGELTKOMPONENTE = "FIXE_LEISTUNGSENTGELTKOMPONENTE"
    UMLAGE_ABSCHALTBARE_LASTEN = "UMLAGE_ABSCHALTBARE_LASTEN"
    MEHRMENGE = "MEHRMENGE"
    MINDERMENGE = "MINDERMENGE"
    ENERGIESTEUER = "ENERGIESTEUER"
    SMARTMETER_GATEWAY = "SMARTMETER_GATEWAY"
    STEUERBOX = "STEUERBOX"
    MSB_INKL_MESSUNG = "MSB_INKL_MESSUNG"
    AUSGLEICHSENERGIE_UNTERDECKUNG = "AUSGLEICHSENERGIE_UNTERDECKUNG"
    ZUSATZDIENSTLEISTUNG_PARAGRAPH_35_2_1_MSBG = "ZUSATZDIENSTLEISTUNG_PARAGRAPH_35_2_1_MSBG"
    ZUSATZDIENSTLEISTUNG_PARAGRAPH_35_2_2_MSBG = "ZUSATZDIENSTLEISTUNG_PARAGRAPH_35_2_2_MSBG"
    ZUSATZDIENSTLEISTUNG_PARAGRAPH_35_2_3_MSBG = "ZUSATZDIENSTLEISTUNG_PARAGRAPH_35_2_3_MSBG"
    ZUSATZDIENSTLEISTUNG_PARAGRAPH_35_2_4_MSBG = "ZUSATZDIENSTLEISTUNG_PARAGRAPH_35_2_4_MSBG"
    ZUSATZDIENSTLEISTUNG_PARAGRAPH_35_2_5_MSBG = "ZUSATZDIENSTLEISTUNG_PARAGRAPH_35_2_5_MSBG"
    ZUSATZDIENSTLEISTUNG_PARAGRAPH_35_3_MSBG = "ZUSATZDIENSTLEISTUNG_PARAGRAPH_35_3_MSBG"
