from enum import Enum


class Rechnungstyp(str, Enum):
    """
    Abbildung verschiedener Rechnungstypen zur Kennzeichnung von Rechnungen
    """

    ENDKUNDENRECHNUNG = "ENDKUNDENRECHNUNG"
    NETZNUTZUNGSRECHNUNG = "NETZNUTZUNGSRECHNUNG"
    MEHRMINDERMENGENRECHNUNG = "MEHRMINDERMENGENRECHNUNG"
    MESSSTELLENBETRIEBSRECHNUNG = "MESSSTELLENBETRIEBSRECHNUNG"
    BESCHAFFUNGSRECHNUNG = "BESCHAFFUNGSRECHNUNG"
    AUSGLEICHSENERGIERECHNUNG = "AUSGLEICHSENERGIERECHNUNG"
    TURNUSRECHNUNG = "TURNUSRECHNUNG"
    ABSCHLAGSRECHNUNG = "ABSCHLAGSRECHNUNG"
    ABSCHLUSSRECHNUNG = "ABSCHLUSSRECHNUNG"
    ZWISCHENRECHNUNG = "ZWISCHENRECHNUNG"
    INTEGRIERTE_13_TE_RECHNUNG = "INTEGRIERTE_13TE_RECHNUNG"
    MONATSRECHNUNG = "MONATSRECHNUNG"
    ZUSAETZLICHE_13_TE_RECHNUNG = "ZUSAETZLICHE_13TE_RECHNUNG"
